"use client";

// src/use-pagination-item.ts
import { useMemo } from "react";
import { PaginationItemType } from "@nextui-org/use-pagination";
import { clsx, dataAttr } from "@nextui-org/shared-utils";
import { chain, mergeProps } from "@react-aria/utils";
import { useDOMRef } from "@nextui-org/dom-utils";
import { useHover, usePress } from "@react-aria/interactions";
import { useFocusRing } from "@react-aria/focus";
var getItemAriaLabel = (page) => {
  if (!page)
    return;
  switch (page) {
    case PaginationItemType.DOTS:
      return "dots element";
    case PaginationItemType.PREV:
      return "previous page button";
    case PaginationItemType.NEXT:
      return "next page button";
    case "first":
      return "first page button";
    case "last":
      return "last page button";
    default:
      return `pagination item ${page}`;
  }
};
function usePaginationItem(props) {
  const {
    as,
    ref,
    value,
    children,
    isActive,
    isDisabled,
    onPress,
    onClick,
    getAriaLabel = getItemAriaLabel,
    className,
    ...otherProps
  } = props;
  const Component = as || "li";
  const domRef = useDOMRef(ref);
  const ariaLabel = useMemo(
    () => isActive ? `${getAriaLabel(value)} active` : getAriaLabel(value),
    [value, isActive]
  );
  const { pressProps } = usePress({
    isDisabled,
    onPress
  });
  const { focusProps, isFocused, isFocusVisible } = useFocusRing({});
  const { isHovered, hoverProps } = useHover({ isDisabled });
  const getItemProps = (props2 = {}) => {
    return {
      ref: domRef,
      role: "button",
      tabIndex: isDisabled ? -1 : 0,
      "aria-label": ariaLabel,
      "aria-current": dataAttr(isActive),
      "aria-disabled": dataAttr(isDisabled),
      "data-disabled": dataAttr(isDisabled),
      "data-active": dataAttr(isActive),
      "data-focus": dataAttr(isFocused),
      "data-hover": dataAttr(isHovered),
      "data-focus-visible": dataAttr(isFocusVisible),
      ...mergeProps(props2, pressProps, focusProps, hoverProps, otherProps),
      className: clsx(className, props2.className),
      onClick: chain(pressProps.onClick, onClick)
    };
  };
  return {
    Component,
    children,
    ariaLabel,
    isFocused,
    isFocusVisible,
    getItemProps
  };
}

export {
  usePaginationItem
};
